package scrabble;

import java.util.Arrays;
import java.util.List;

/**
 * Holder for tiles. Holder is ordered (has positions (index)).
 *
 * @author hajo
 *
 */
public final class Holder {

    // Holding Tile and position
    private final Tile[] tiles;

    public Holder(int maxTiles) {
        tiles = new Tile[maxTiles];
    }

    public Holder() {
        this(ScrabbleOptions.getMaxHolder());
    }

    public boolean add(Tile tile) {
        for (int i = 0; i < tiles.length; i++) {
            if (tiles[i] == null) {
                tiles[i] = tile;
                return true;
            }
        }
        return false;
    }

    public Tile remove(int index) {
        Tile t = tiles[index];
        tiles[index] = null;
        return t;
    }

    public List<Tile> getTiles() {
        return Arrays.asList(tiles);
    }

    public int actualSize() {
        int empty = 0;
        for (int i = 0; i < size(); i++) {
            if (tiles[i] == null) {
                empty++;
            }
        }
        return size() - empty;
    }

    public int size() {
        return tiles.length;
    }

    @Override
    public String toString() {
        StringBuilder s = new StringBuilder();
        for (Tile t : tiles) {
            s.append(t).append(",");
        }
        return s.toString();
    }
}
