package scrabble;

/**
 * A position on the Scrabble board
 *
 * @author hajo
 *
 */
public class Position {

    private final int row;
    private final int col;
    private final Bonus bonus; // Possible bonus for this position
    private final Tile tile;

    // An inner enum
    public enum Bonus {

        NONE, DL, TL, DW, TW;
    }
    
    public Position(int row, int col) {
        this(row, col, null, Bonus.NONE);
    }

    public Position(int row, int col, Tile tile) {
        this(row, col, tile, Bonus.NONE);
    }

    public Position(int row, int col, Tile tile, Bonus bonus) {
        this.row = row;
        this.col = col;
        this.tile = tile;
        this.bonus = bonus;
    }

    public int getRow() {
        return row;
    }

    public Tile getTile() {
        return tile;
    }

    public int getCol() {
        return col;
    }

    public Bonus getBonus() {
        return bonus;
    }

    @Override
    public String toString() {
        return "[" + row + "," + col + "]";
    }

    // Very important if using a Set
    @Override
    public int hashCode() {
        int hash = 7;
        hash = 83 * hash + this.row;
        hash = 83 * hash + this.col;
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Position other = (Position) obj;
        if (this.row != other.row) {
            return false;
        }
        if (this.col != other.col) {
            return false;
        }
        return true;
    }  
}
