package scrabble.test;

import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;
import scrabble.Player;
import scrabble.Position;
import scrabble.Scrabble;
import scrabble.ScrabbleOptions;
import scrabble.Tile;
import scrabble.TileBag;

public class TestCommandLine {

    public static void commandLine() {
        List<Position> tilesToPlace = new ArrayList<>();
        List<Tile> tiles = getTiles();
        TileBag bag = new TileBag(tiles);
        Scrabble scrabble = new Scrabble(ScrabbleOptions.getPlayerNames(), bag, 5, 5);
        scrabble.start();
        Player actual = scrabble.getActualPlayer();
        System.out.println("h for help on commands");
        Scanner s = new Scanner(System.in);
        while (true) {
            System.out.println(actual);
            System.out.print("> ");
            String cmd = s.nextLine();
            switch (cmd) {
                case "h":
                    help();
                    break;
                case "q":
                    System.exit(0);
                    break;
                case "t":
                    System.out.print("Enter index for tile to pick and position to place> ");
                    int index = s.nextInt();
                    int row = s.nextInt();
                    int col = s.nextInt();
                    s.nextLine();  // Remove trailing chars
                    actual = scrabble.getActualPlayer();
                    Tile t = actual.pickTileFromHolder(index);
                    tilesToPlace.add(new Position(row, col, t));
                    break;
                case "p":
                    actual = scrabble.getActualPlayer();
                    if (scrabble.putTiles(tilesToPlace)) {
                        actual.pickNewTilesFromBag();
                    } else {
                        for (Position pos : tilesToPlace) {
                            actual.putBackTile(pos.getTile());
                        }
                    }
                    tilesToPlace.clear();
                    break;
                case "n":
                    scrabble.nextPlayer();
                    break;
                case "d":
                    System.out.println(scrabble.toString());
                    break;
                default:
                    System.out.println("?");
            }
        }

    }

    public static void main(String args[]) {
        commandLine();
    }

    private static void help() {
        System.out.println("q = quit");
        System.out.println("n = next player");
        System.out.println("p = place selected tiles");
        System.out.println("t = pick a tile");
        System.out.println("d = dump game to System.out");
    }

    // This should be read from file, just for now
    private static List<Tile> getTiles() {
        List<Tile> tiles = new ArrayList<>();
        tiles.add(new Tile("A", 1));
        tiles.add(new Tile("A", 1));
        tiles.add(new Tile("A", 1));
        tiles.add(new Tile("A", 1));
        tiles.add(new Tile("S", 1));
        tiles.add(new Tile("S", 1));
        tiles.add(new Tile("M", 1));
        tiles.add(new Tile("M", 1));
        tiles.add(new Tile("T", 1));
        tiles.add(new Tile("T", 1));
        return tiles;
    }
}
